@@ -303,14 +303,21 @@ def contin(datalist, Ngrid=256, tmin=-2, tmax=-2, bgr=0, distribution='dls', RDG
      fp1=np.trapz(ff.Y[p1],ff.X[p1])/np.trapz(ff.Y,ff.X) # fraction of full signal
 
     **An example dataset with noise**
-    In this synthetic example the noise causes a peak width of about 22% (std/mean) as it is
+    In this synthetic example the noise causes a peak width of about 20% (std/mean) as it is
     typically found for monodisperse samples (e.g. proteins).
     This contribution is not caused by polydispersity and always present dependent on noise level.
+
+    D = 0.05 nm²/ns corresponds to a hydrodynamic radius of 4.3 nm and results in a
+    relaxation time :math:`\Gamma= q^2D \approx 90.2 µs`.
+
+    The below plot shows the CONTIN result as correlation time distribution
+    with mean 92 µs ±17 µs and peak weight 95% in good approximation.
+
     ::
 
      import jscatter as js
      import numpy as np
-     t=js.loglist(1,100000,1000)   #times in microseconds
+     t=js.loglist(1,10000,1000)   #times in microseconds
      q=4*np.pi/1.333/632*np.sin(np.pi/2) # 90 degrees for 632 nm , unit is 1/nm**2
      D=0.05*1000  # nm**2/ns * 1000 = units nm**2/microseconds
      noise=0.0001  # typical < 1e-3
