@@ -126,6 +126,12 @@ relError=0.02 samples until the error is smaller 0.02 for a q point with pseudor
 The same can be done with relError=400 on a fixed Fibonacci lattice.
 Both need longer for the computation.  
 
+The 1/q² power law at low q for the analytic model results from integration over
+infinite, d=3 dimensional q space. 
+For a real nanoparticle or crystal domain the size (~ integration volume ) is finite resulting in the typical 
+formfactor behaviour with a plateau for lowest q, a Guinier range determined by Rg
+and a Porod region at higher q dependent on the fractal stucture.  
+
 #end3
 """
 
